@@ -2,6 +2,13 @@ import httpx
 
 from statuscheck.services.bases._base import BaseServiceAPI
 from statuscheck.services.models.generic import (
+    COMPONENT_TYPE_DEGRADED,
+    COMPONENT_TYPE_GOOD,
+    COMPONENT_TYPE_MAINTENANCE,
+    COMPONENT_TYPE_MAJOR_OUTAGE,
+    COMPONENT_TYPE_PARTIAL_OUTAGE,
+    COMPONENT_TYPE_SECURITY,
+    COMPONENT_TYPE_UNKNOWN,
     TYPE_GOOD,
     TYPE_INCIDENT,
     TYPE_MAINTENANCE,
@@ -29,6 +36,24 @@ STATUS_TYPE_MAPPING = {
     STATUS_SECURITY: TYPE_SECURITY,
 }
 
+COMPONENT_STATUS_GOOD = 100
+COMPONENT_STATUS_MAINTENANCE = 200
+COMPONENT_STATUS_DEGRADED = 300
+COMPONENT_STATUS_PARTIAL_OUTAGE = 400
+COMPONENT_STATUS_MAJOR_OUTAGE = 500
+COMPONENT_STATUS_SECURITY = 600
+COMPONENT_STATUS_UNKNOWN = ""
+
+COMPONENT_STATUS_MAPPING = {
+    COMPONENT_STATUS_GOOD: COMPONENT_TYPE_GOOD,
+    COMPONENT_STATUS_MAINTENANCE: COMPONENT_TYPE_MAINTENANCE,
+    COMPONENT_STATUS_DEGRADED: COMPONENT_TYPE_DEGRADED,
+    COMPONENT_STATUS_PARTIAL_OUTAGE: COMPONENT_TYPE_PARTIAL_OUTAGE,
+    COMPONENT_STATUS_MAJOR_OUTAGE: COMPONENT_TYPE_MAJOR_OUTAGE,
+    COMPONENT_STATUS_SECURITY: COMPONENT_TYPE_SECURITY,
+    COMPONENT_STATUS_UNKNOWN: COMPONENT_TYPE_UNKNOWN,
+}
+
 
 class BaseStatusIOAPI(BaseServiceAPI):
     """
@@ -60,7 +85,7 @@ class BaseStatusIOAPI(BaseServiceAPI):
             Component(
                 id=component["id"],
                 name=component["name"],
-                status=component["status"],
+                status=COMPONENT_STATUS_MAPPING[component["status_code"]],
                 extra_data=component,
             )
             for component in response_json["result"]["status"]
