@@ -2,12 +2,13 @@ import respx
 from httpx import Response
 
 from statuscheck.services.bases._statuspageio import STATUS_MAINTENANCE
+from statuscheck.services.models.generic import COMPONENT_TYPE_MAINTENANCE
 from statuscheck.utils import get_statuscheck_api
 
 
 class TestCloudAMQP:
     @respx.mock
-    def test_ok(self):
+    def test_maintenance(self):
         with open(
             "tests/test_services/test_data/cloudamqp_maintenance.json", "rb"
         ) as f:
@@ -31,3 +32,6 @@ class TestCloudAMQP:
         assert service_api.summary.status.code == STATUS_MAINTENANCE
         assert len(service_api.summary.incidents) == 1
         assert len(service_api.summary.components) == 23
+
+        component = service_api.summary.components[0]
+        assert component.status == COMPONENT_TYPE_MAINTENANCE
