@@ -2,12 +2,13 @@ import respx
 from httpx import Response
 
 from statuscheck.services.bases._statuspageio import STATUS_MAJOR
+from statuscheck.services.models.generic import COMPONENT_TYPE_PARTIAL_OUTAGE
 from statuscheck.utils import get_statuscheck_api
 
 
 class TestGithub:
     @respx.mock
-    def test_ok(self):
+    def test_incident(self):
         with open("tests/test_services/test_data/github_incident.json", "rb") as f:
             mock_response_body = f.read()
         respx.get(
@@ -29,3 +30,6 @@ class TestGithub:
         assert service_api.summary.status.code == STATUS_MAJOR
         assert len(service_api.summary.incidents) == 3
         assert len(service_api.summary.components) == 2
+
+        component = service_api.summary.components[0]
+        assert component.status == COMPONENT_TYPE_PARTIAL_OUTAGE
