@@ -1,13 +1,14 @@
 import respx
 from httpx import Response
 
+from statuscheck.services.models.generic import COMPONENT_TYPE_PARTIAL_OUTAGE
 from statuscheck.services.salesforce import STATUS_CORE_INCIDENT
 from statuscheck.utils import get_statuscheck_api
 
 
 class TestSalesforce:
     @respx.mock
-    def test_ok(self):
+    def test_incident(self):
         with open("tests/test_services/test_data/salesforce_incident.json", "rb") as f:
             mock_response_body = f.read()
         respx.get(
@@ -37,3 +38,6 @@ class TestSalesforce:
         assert service_api.summary.status.code == STATUS_CORE_INCIDENT
         assert len(service_api.summary.incidents) == 1
         assert len(service_api.summary.components) == 1
+
+        component = service_api.summary.components[0]
+        assert component.status == COMPONENT_TYPE_PARTIAL_OUTAGE
